/******************************************************************************/
/*                                                                            */
/*                           P C I - B I O S   V1.13                          */
/*                                                                            */
/*                          PCI-Bios fr HADES040/060                         */
/*                                                                            */
/*  Modul:         PCI-BIOS (PCI_BIOS.PRG)                                    */
/*  File:          PCI_INT.H                                                  */
/*  Beschreibung:  BIOS-interne Deklarationen                                 */
/*                                                                            */
/*  (c)1997-2000 Markus Fichtenbauer                              03.08.2000  */
/*                                                                            */
/******************************************************************************/
/* $Id$ */
/******************************************************************************/
/* $Log$ */
/******************************************************************************/

#if !defined( __PCI_INTERN__ )
#define __PCI_INTERN__

/******************************************************************************/
/*                                                                            */
/*                            Datentyp-Deklarationen                          */
/*                                                                            */
/******************************************************************************/
typedef LONG (*PROCREF)();

typedef struct                         /* Aufbau einer XBRA-Kennung           */
{
  ULONG   xbra_id;                     /* Kennung 'XBRA'                      */
  ULONG   xbra_val;                    /* Programmkennung (_PCI)              */
  ULONG   xbra_adr;                    /* Wert (Adresse des Routinenpools)    */
} XBRA;

typedef struct                         /* Aufbau eines Cookie-Eintrags        */
{
  LONG    magic;                       /* Cookie - ID                         */
  LONG    value;                       /* Wert des Cookies                    */
} COOKIE_ENTRY;

typedef struct                         /* Aufbau des _PCI - Cookies           */
{
  ULONG   *subcookie;                  /* Sub-Cookie von PCI_CONF             */
  ULONG   version;                     /* Versionsnummer des PCI-Bios         */
  PROCREF routine[45];                 /* Platz fr die Adressen der Routinen */
} PCI_COOKIE;

typedef struct                         /* Aufbau des Ressource-Descriptors    */
{                                      /* fr die interne Verwendung im BIOS! */
  struct                               /* die "ffentliche" Struktur steht in */
  {                                    /* der Header-Datei 'PCI_BIOS.H'       */
    UWORD next;                        /* Laenge dieser Struktur              */
    UWORD flags;                       /* Art der Resource und versch. Flags  */
    ULONG start;                       /* Startadresse der Resource           */
    ULONG length;                      /* Lnge der Resource                  */
    ULONG offset;                      /* Offset PCI zu phys. CPU Adresse     */
    ULONG dmaoffset;                   /* Offset fr DMA-Transfers            */
  } RESOURCE[6];                       /* max. 6 Resourcen je Karte mglich   */
} PCI_RSC_DESC_I;

typedef struct                         /* Aufbau des Status-Descriptors       */
{
  LONG status;                         /* Status des PCI-Gerts               */
  ULONG callback;                      /* Adresse der Callback-Routine        */
  ULONG handler;                       /* Adresse des Interrupt-Handlers      */
  ULONG parameter;                     /* Parameter fr Interrupt-Handler     */
  ULONG start_irq;                     /* Routine fr das Starten der IRQ's   */
} PCI_DEV_DESC;

/******************************************************************************/
/*                                                                            */
/*                      Konstante Daten und Definitionen                      */
/*                                                                            */
/******************************************************************************/
/*                       PCI-Bios Programminformationen                       */
/******************************************************************************/
#define BIOS_Vers      "1.13c"         /* PCI-BIOS Version                    */
#define BIOS_Date      "03.08.2000"    /* PCI-BIOS Erstellungsdatum           */
#define BIOS_Rev       0x10000L        /* Versionsnummer des BIOS-Interface   */

/******************************************************************************/
/*                       Cookie und XBRA - Definitionen                       */
/******************************************************************************/
#define _p_cookies	   0x000005A0L     /* Adresse Systemvariable Cookie Jar   */
#define COOKIE_HADES   0x68616465L     /* 'hade'  Hades Cookie                */
#define COOKIE_PCI     0x5F504349L     /* '_PCI'  PCI-Bios Cookie             */
#define XBRA_ID        0x58425241L     /* 'XBRA'  XBRA ID                     */
#define SYS_HADES      0x01L           /* Systeminfo.0: HADES erkannt         */
#define SYS_PCIBIOS    0x02L           /* Systeminfo.1: PCI-BIOS installiert  */
#define SYS_PCICONF    0x04L           /* Systeminfo.2: PCI_CONF installiert  */

/******************************************************************************/
/*                     Masken fr I/O und Memory-Bereiche                     */
/******************************************************************************/
#define IO_SPACE       0x00000001L     /* IO space indicator                  */
#define MEM_TP32       0               /* Bereich innerhalb 32 bit Adr.raum   */
#define MEM_TP1M       1               /* Bereich unterhalb 1 MB              */
#define MEM_TP64       2               /* Bereich innerhalb 64 bit Adr.raum   */

/******************************************************************************/
/*         Hardware-abhngige Einstellungen der PCI-Speicher-Bereiche         */
/******************************************************************************/
#define IO_OFFSET      0xB0000000L     /* Beginn des IO-Bereichs              */
#define IO_SIZE        0x0FFFFFFFL     /* Gre des IO-Bereichs (256 MB)      */
#define MEMORY_OFFSET  0x80000000L     /* Beginn des Memory-Bereichs          */
#define MEMORY_SIZE    0x1FFFFFFFL     /* Gre des Memory-Bereichs (512 MB)  */
#define DMA_OFFSET     0x80000000L     /* Offset DMA-Bereich vom PCI-Bus aus  */
#define DMA_MASK       DMA_OFFSET      /* vom PCI-Bus aus ist Bit31 gesetzt   */
#define RAM_SIZE       0x3FFFFFFFL     /* Gre des RAM-Bereichs (3 GB)       */

/******************************************************************************/
/*   Einstellungen fr nicht ganz PCI-konforme Grafikkarten (ET4000/ET6000)   */
/******************************************************************************/
#define TSENG_ETx000   0x3200100CL     /* Configuration ID fuer Tseng ETx000  */
#define TSENG_ETMASK   0xFFF0FFFFL     /* Maske fuer Devices ET4000 / ET6000  */
#define GK_IOOFF       0               /* Offset des IO-Bereichs              */
#define GK_IOSIZE      0x1000L         /* Gre des IO-Bereichs               */
#define GK_MEMOFF      0               /* Offset des Memory-Bereichs          */
#define GK_MEMSIZE     0x1000000L      /* Gre des Memory-Bereichs           */

/******************************************************************************/
/*                       Flags im Resource-Deskriptor                         */
/******************************************************************************/
#define FLG_DEF    0x0702              /* Default-Flags fr Hades             */

/******************************************************************************/
/*                          HADES - Seriennummer                              */
/******************************************************************************/
#define SER_NR     0x7FE49000          /* Adresse der Hades-Seriennummer      */

/******************************************************************************/
/*                  Masken fr das Command and Status Register                */
/******************************************************************************/
#define IO_CTRL    0x00000001L         /* Karte reagiert auf IO-Zugriffe      */
#define MEM_CTRL   0x00000002L         /* Karte reagiert auf Memory-Zugriffe  */
#define DMA_CTRL   0x00000004L         /* Karte darf als Busmaster agieren    */
#define SC_CTRL    0x00000008L         /* Karte reagiert auf Special Cycles   */

/******************************************************************************/
/*                Einstellungen fr das Latency Timer Register                */
/******************************************************************************/
#define LT_DEF     32                  /* 32 PCI bus clocks als default-Wert  */

/******************************************************************************/
/*                                                                            */
/*                            Deklarationen zum Debuggen                      */
/*                                                                            */
/******************************************************************************/
#undef DEBUG_FILE
#undef DEBUG_SCREEN

#ifdef DEBUG_MODEM
  #define TRACEB(flag)    sprintf(tr_buffer,#flag "=%02x\n\r",flag);\
                          dpy=tr_buffer;while(*dpy)(Bconout(6,*dpy++));
  #define TRACEW(flag)    sprintf(tr_buffer,#flag "=%04x\n\r",flag);\
                          dpy=tr_buffer;while(*dpy)(Bconout(6,*dpy++));
  #define TRACEL(flag)    sprintf(tr_buffer,#flag "=%p\n\r",flag);\
                          dpy=tr_buffer;while(*dpy)(Bconout(6,*dpy++));
  #define TRACES(flag)    sprintf(tr_buffer,#flag "=%s\n\r",flag);\
                          dpy=tr_buffer;while(*dpy)(Bconout(6,*dpy++));
  #define TRACET(x)       dpy=x;while(*dpy)(Bconout(6,*dpy++));
#endif

#ifdef DEBUG_SCREEN
  #define TRACEB(flag)    printf(#flag "=%02x\n",flag);
  #define TRACEW(flag)    printf(#flag "=%04x\n",flag);
  #define TRACEL(flag)    printf(#flag "=%p\n",flag);
  #define TRACES(flag)    printf(#flag "=%s\n",flag);
  #define TRACET(flag)    printf(#flag "\n");
#endif

/******************************************************************************/
/*                                                                            */
/*                                Globale Makros                              */
/*                                                                            */
/******************************************************************************/
#define MIN(a,b)  (((a)<(b))? (a):(b))          /* Minimumbildung             */
#define MAX(a,b)  (((a)>(b))? (a):(b))          /* Maximumbildung             */
#define HIGHW(x)  ((x>>16) & 0xFFFFL)           /* Makro fr Higher word      */
#define HIGHB(x)  ((x>>8) & 0xFFL)              /* Makro fr Highbyte         */
#define HIGHN(x)  ((x>>4) & 0xFL)               /* Makro fr Highnibble       */
#define LOWW(x)   (x & 0xFFFFL)                 /* Makro fr Lower word       */
#define LOWB(x)   (x & 0xFFL)                   /* Makro fr Lowbyte          */
#define LOWN(x)   (x & 0xFL)                    /* Makro fr Lownibble        */
#define SWAPB(x)  ((x >> 8) | (x << 8))         /* High/Low tauschen          */

#define VendorID(x)       ((UWORD)(x))          /* Vendor ID                  */
#define DeviceID(x)       ((UWORD)(x >> 16))    /* Device ID                  */
#define Baseclass(x)      ((UBYTE)(x >> 24))    /* Base Class des ClassCodes  */
#define Subclass(x)       ((UBYTE)(x >> 16))    /* Sub Class des ClassCodes   */
#define Progif(x)         ((UBYTE)(x >> 8))     /* Programming interface      */
#define CheckBaseclass(x) (x & 0x04000000L)     /* Base Class berprfen ?    */
#define CheckSubclass(x)  (x & 0x02000000L)     /* Sub Class berprfen ?     */
#define CheckInterface(x) (x & 0x01000000L)     /* Prog. If. berprfen ?     */
#define ResourceType(x)   ((UBYTE)((x >> 1)&3)) /* Memory Type (I/O - MEM)    */

#endif                                 /* __PCI_INTERN__                      */

